@@ -24,8 +24,8 @@ import time
 
 VERSION = '0.9.7'
 
-sys.path.append(sys.path[0] + '/..')
-os.environ['PYTHONPATH'] = sys.path[0] + '/..'
+#sys.path.append(sys.path[0] + '/..')
+#os.environ['PYTHONPATH'] = sys.path[0] + '/..'
 
 
 def mem(pid, size="rss"):
@@ -79,7 +79,7 @@ def main():
     try:
         exec "import " + settingsmodule + " as settings"
     except ImportError:
-        print >>sys.stderr, "[CLAM Dispatcher] FATAL ERROR: Unable to import settings module"
+        print >>sys.stderr, "[CLAM Dispatcher] FATAL ERROR: Unable to import settings module, settingsmodule is " + settingsmodule
         f = open(projectdir + '.done','w')
         f.write(str(1))
         f.close()
